==> gtphoto2-framework-0.1.tar.gz: gtphoto2/includes/sql_wrappers.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# this script provides wrappers for all of the database functions

function sql_connect($host, $user, $password) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_connect($host, $user, $password));
	}
}

function sql_select_db($database) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_select_db($database));
	}
}

function sql_query($sql) {
	if (DEBUG) {
		echo ("SQL Query: $sql<br />");
	}
	global $total_sql_queries;
	if (DATABASE_TYPE == "mysql") {
		$result = mysql_query($sql);
		if (mysql_error()) {
			puke ("SQL Query failed: $sql<br /><br />Error: ".mysql_error());
		} else {
			$total_sql_queries++;
			return($result);
		}
	}
}

function sql_fetch_array($result) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_fetch_array($result));
	}
}

function sql_num_rows($result) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_num_rows($result));
	}
}

?>

==> gtphoto2-framework-0.2.tar.gz: gtphoto2/includes/sql_wrappers.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# this script provides wrappers for all of the database functions

function sql_connect($host, $user, $password) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_connect($host, $user, $password));
	} elseif (DATABASE_TYPE == "mysqli") {
		global $db_link;
		$db_link = mysqli_connect($host, $user, $password);
		return $db_link;
	}
}

function sql_select_db($database) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_select_db($database));
	} elseif (DATABASE_TYPE == "mysqli") {
		global $db_link;
		return(mysqli_select_db($db_link,$database));
	}
}

function sql_query($sql) {
	if (DEBUG) {
		echo ("<p>SQL Query: ".$sql."</p>");
	}
	if (DATABASE_TYPE == "mysql") {
		$result = mysql_query($sql);
		if (mysql_error()) {
			puke("Mysql Error: ".mysql_error());
		} else {
			global $total_sql_queries;
			$total_sql_queries++;
			return $result;
		}
	} elseif (DATABASE_TYPE == "mysqli") {
		global $db_link;
		$result = mysqli_query($db_link,$sql);
		if (mysqli_error($db_link)) {
			puke("Mysql Error: ".mysqli_error($db_link));
		} else {
			global $total_sql_queries;
			$total_sql_queries++;
			return $result;
		}
	}
}

function sql_fetch_array($result) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_fetch_array($result));
	} elseif (DATABASE_TYPE == "mysqli") {
		return(mysqli_fetch_array($result));
	}
}

function sql_fetch_assoc($result) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_fetch_assoc($result));
	} elseif (DATABASE_TYPE == "mysqli") {
		return(mysqli_fetch_assoc($result));
	}
}

function sql_fetch_row($result) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_fetch_row($result));
	} elseif (DATABASE_TYPE == "mysqli") {
		return(mysqli_fetch_row($result));
	}
}

function sql_num_rows($result) {
	if (DATABASE_TYPE == "mysql") {
		return(mysql_num_rows($result));
	} elseif (DATABASE_TYPE == "mysqli") {
		return(mysqli_num_rows($result));
	}
}

?>
